@@ -116,6 +116,9 @@ int bch2_sb_members_v2_init(struct bch_fs *c)
 				DIV_ROUND_UP(sizeof(*mi2) +
 					     sizeof(struct bch_member) * c->sb.nr_devices,
 					     sizeof(u64)));
+		if (!mi2)
+			return bch_err_throw(c, ENOSPC_sb_members_v2);
+
 		mi1 = bch2_sb_field_get(c->disk_sb.sb, members_v1);
 		memcpy(&mi2->_members[0], &mi1->_members[0],
 		       BCH_MEMBER_V1_BYTES * c->sb.nr_devices);
@@ -377,7 +380,9 @@ static int bch2_sb_members_v1_validate(struct bch_sb *sb, struct bch_sb_field *f
 	return 0;
 }
 
-static void bch2_sb_members_v1_to_text(struct printbuf *out, struct bch_sb *sb,
+static void bch2_sb_members_v1_to_text(struct printbuf *out,
+				       struct bch_fs *c,
+				       struct bch_sb *sb,
 				       struct bch_sb_field *f)
 {
 	struct bch_sb_field_members_v1 *mi = field_to_type(f, members_v1);
@@ -401,7 +406,9 @@ const struct bch_sb_field_ops bch_sb_field_ops_members_v1 = {
 	.to_text	= bch2_sb_members_v1_to_text,
 };
 
-static void bch2_sb_members_v2_to_text(struct printbuf *out, struct bch_sb *sb,
+static void bch2_sb_members_v2_to_text(struct printbuf *out,
+				       struct bch_fs *c,
+				       struct bch_sb *sb,
 				       struct bch_sb_field *f)
 {
 	struct bch_sb_field_members_v2 *mi = field_to_type(f, members_v2);
